@@ -29,7 +29,7 @@ def generate_engine(**options):
             f"postgresql+psycopg2://{options['user']}:{options['password']}@{options['host']}:{options['port']}/{options['dbname']}"
         )
     if options["type"] == "snowflake":
-        connect_args = None
+        connect_args = {}
         if "private_key_path" in options and options["private_key_path"]:
             with open(options["private_key_path"], "rb") as key:
                 p_key = serialization.load_pem_private_key(
@@ -60,7 +60,7 @@ def generate_engine(**options):
                 role=options["role"],
                 authenticator=options["authenticator"]
                 if "authenticator" in options and options["authenticator"]
-                else None,
+                else "",
             ),
             connect_args=connect_args,
         )
@@ -274,12 +274,12 @@ def _create_table_sql(table, engine):
     return str(sa.schema.CreateTable(table).compile(engine)) + ";"
 
 
-def _create_namespace_sql(namespace, clean=False):
-    sql = ""
-    if clean:
-        sql += f"DROP SCHEMA IF EXISTS {namespace} CASCADE; "
-    sql += f"CREATE SCHEMA {namespace}; "
-    return sql
+def _clean_namespace_sql(namespace):
+    return f"DROP SCHEMA IF EXISTS {namespace} CASCADE;"
+
+
+def _create_namespace_sql(namespace):
+    return f"CREATE SCHEMA IF NOT EXISTS {namespace};"
 
 
 def init_test_db(env, engine, schemas_path, clean=False):
@@ -287,9 +287,12 @@ def init_test_db(env, engine, schemas_path, clean=False):
 
     schema_metadata = read_sa_metadata(schemas_path)[env]
 
+    clean_schema_sqls = [
+        _clean_namespace_sql(namespace) for namespace in schema_metadata.keys() if clean
+    ]
+
     create_schema_sqls = [
-        _create_namespace_sql(namespace, clean=clean)
-        for namespace in schema_metadata.keys()
+        _create_namespace_sql(namespace) for namespace in schema_metadata.keys()
     ]
 
     create_table_sqls = [
@@ -298,6 +301,7 @@ def init_test_db(env, engine, schemas_path, clean=False):
         for table_name, table in tables.items()
     ]
 
+    execute_sqls(engine, clean_schema_sqls)
     execute_sqls(engine, create_schema_sqls)
     execute_sqls(engine, create_table_sqls)
 
@@ -308,14 +312,14 @@ def clean_target_test_data(engine, api):
 
     namespaces = {target.split(".")[1] for target in api.spec["targets"].keys()}
     for namespace in namespaces:
+        execute_sqls(engine, [f"CREATE SCHEMA IF NOT EXISTS {namespace}"])
+
         tables = engine.table_names(schema=namespace)
         LOG.debug("Found existing tables: %s", tables)
 
         views = list(insp.get_view_names(schema=namespace))
         LOG.debug("Found existing views: %s", views)
 
-        execute_sqls(engine, [f"CREATE SCHEMA IF NOT EXISTS {namespace}"])
-
         targets = api.spec["targets"].keys()
         target_tables = [
             target for target in targets if target.split(".")[-1] in tables
@@ -333,17 +337,17 @@ def clean_target_test_data(engine, api):
         )
 
 
-def serialize(data):
-    "Converts data specified in a dtspec yaml table and serializes it prior to loading into a test database"
+def sa_serialize(data):
+    "Converts data specified in a dtspec yaml table and serializes it prior to loading via sqlalchemy"
 
     serialized_data = []
     for row in data:
         serialized_row = {}
         for k, v in row.items():
             if v == "{True}":
-                serialized_row[k] = "True"
+                serialized_row[k] = True
             elif v == "{False}":
-                serialized_row[k] = "False"
+                serialized_row[k] = False
             else:
                 serialized_row[k] = v
 
@@ -376,6 +380,7 @@ def load_test_data(source_engines, api, schemas_path):
     truncate_by_env_sqls = {env: [] for env in source_engines.keys()}
     insert_by_env_sqls = {env: [] for env in source_engines.keys()}
     for source_name, data in api.spec["sources"].items():
+
         try:
             this_source_meta = source_fqn_to_sa[source_name]
         except KeyError as err:
@@ -385,7 +390,7 @@ def load_test_data(source_engines, api, schemas_path):
         source_insert = (
             this_source_meta["sa_table"]
             .insert(bind=this_source_meta["engine"])
-            .values(data.serialize())
+            .values(sa_serialize(data.serialize()))
         )
 
         truncate_by_env_sqls[this_source_meta["env"]].append(
